Thank you for your detailed and useful feedback.

We now address your concerns by category:

# Novelty of Contribution

## Meaningfulness and Durability
We agree that clearer definitions and justifications of durability and meaningfulness are needed.

In short, a discrepancy between two HTTP servers is durable if it is possible to trigger it even after applying the normalizations of a transducer, and it is meaningful if it implies a violation of the HTTP specification on the part of either server.

Durability is clearly a necessary condition for a discrepancy to lead to request smuggling. This is because an discrepancy that is not durable is by definition either rejected or effectively neutralized by the frontend proxy.

Meaningfulness *may* not be a necessary condition for request smuggling, but we argue that it very likely is. Request smuggling has been known since 2005. The modern RFCs were written with care to disallow request smuggling between compliant implementations. All request smuggling vulnerabilities discovered after 2005 exploit violations of the specification.

## Relationship to Prior Work

### T-Reqs and HDiff

The topology of the testing network is the same between T-Reqs, HDiff, and the HTTP Garden.

We differ from prior work in that our fuzzer is evolutionary instead of fixed-depth, coverage-guided instead of black-box, examines the entire parsed request instead of only certain constructs (e.g. the message body, specific header values), filters false positives using necessary conditions for exploitability instead of overreporting, and has a lower barrier to integrate new target HTTP servers.

### NEZHA

The only technique we use from NEZHA is the method for evaluating seeds ($\delta$-diversity). All other techniques are our own, including mutation strategies.

Differences between our work and NEZHA include that NEZHA targets only locally running programs, it employs a naive mutator, it does not examine program output beyond exit statuses, it documents no attempt to reduce redundant output, and it requires all target programs to support coverage collection.

# Missing Details

We agree that we should add further details about the following during the revision period:
1. The exploitability, use case (e.g. smuggling, DoS), patch status, and CVE status of each discovered bug,
2. Whether prior work could detect each discovered bug,
2. The impact of request smuggling vulnerabilities in general, (e.g. when is access control bypass possible? Stream desynchronization? Cache poisoning?)
3. The operation of the 13 mutations used in our fuzzer, and how we avoid applying mutations that cannot apply (e.g., grammar-based mutations for inputs that are no longer parsable),
4. The mechanism of the meaningfulness evaluation.

# Evaluation

We agree that our work needs more evaluation. In particular, we agree that it would benefit from the following:
1. Ablation studies to evaluate choices made about the fuzzer.
2. General performance analysis (inputs generated/sec, total running time, code coverage trend)

We would be happy to add these in revisions.

# Figures and Formatting

We agree with all concerns about figures and formatting, and will address them in revisions.